@@ -1,25 +1,36 @@
-"""
+""" Implementation of Acts in POM model
 (c) Joaquim Carvalho 2021.
 MIT License, no warranties.
 """
 from sqlalchemy import Column, String, ForeignKey
 
-from timelink.mhk.models.base import Entity
+from timelink.mhk.models.entity import Entity
 
 
 class Act(Entity):
+    """Represents an Act, i.e. a record of some event in a historical document.
+
+    Examples of acts are: baptisms, marriages, purchase deeds, wills,
+    court records.
+    """
+
     __tablename__ = "acts"
 
+    #: str:  a string uniquely identifying the act
     id = Column(String, ForeignKey("entities.id"), primary_key=True)
+    #: str: the type of the act
     the_type = Column(String(32))
-    the_date = Column(String)
+    #: str: the date of the act in Kleio format AAAAMMDD
+    the_date = Column(String, index=True)
+    #: str: location of the act, eg church, notary office
     loc = Column(String)
-    ref = Column(String)
-    obs = Column(String)
+    ref = Column(String)  #: str: archival reference
+    obs = Column(String)  #: any observations or comments.
 
     __mapper_args__ = {"polymorphic_identity": "act"}
 
     def __repr__(self):
+        """String can be used to instantiate an Act"""
         sr = super().__repr__()
         return (
             f"Act(id={sr}, "
@@ -27,7 +38,7 @@ class Act(Entity):
             f'the_date="{self.the_date}", '
             f'local="{self.loc}", '
             f'ref="{self.ref}", '
-            f"obs={self.obs}"
+            f'obs="{self.obs}"'
             f")"
         )
 
